@@ -29,42 +29,6 @@ get_dot_data <- function(data, dots) {
 dot_names <- function(dots) unname(unlist(lapply(dots, as.character)))
 
 
-#' @importFrom sjmisc str_contains to_label to_value replace_na word_wrap
-#' @importFrom sjstats resp_val resp_var
-get_lm_data <- function(fit) {
-  if (inherits(fit, "plm")) {
-    # plm objects have different structure than (g)lm
-    fit_x <- data.frame(cbind(as.vector(fit$model[, 1]), stats::model.matrix(fit)))
-    # retrieve response vector
-    resp <- sjstats::resp_val(fit)
-    depvar.label <- sjstats::resp_var(fit)
-  } else if (inherits(fit, "pggls")) {
-    # plm objects have different structure than (g)lm
-    fit_x <- data.frame(fit$model)
-    depvar.label <- attr(attr(attr(fit$model, "terms"), "dataClasses"), "names")[1]
-    # retrieve response vector
-    resp <- as.vector(fit$model[, 1])
-  } else if (is_merMod(fit)) {
-    fit_x <- data.frame(stats::model.matrix(fit))
-    # retrieve response vector
-    resp <- stats::model.frame(fit)[[1]]
-    depvar.label <- sjstats::resp_var(fit)
-  } else if (inherits(fit, "gls")) {
-    fit_x <- data.frame(stats::model.matrix(fit))
-    resp <- nlme::getResponse(fit)
-    depvar.label <- attr(resp, "label")
-  } else {
-    fit_x <- data.frame(stats::model.matrix(fit))
-    # retrieve response vector
-    resp <- stats::model.frame(fit)[[1]]
-    depvar.label <- sjstats::resp_var(fit)
-  }
-  # get variable label label
-  depvar.label <- unname(sjlabelled::get_label(x = resp, def.value = depvar.label))
-  return(list(matrix = fit_x, resp.label = depvar.label, resp = resp))
-}
-
-
 # add annotations with table summary
 # here we print out total N of cases, chi-square and significance of the table
 print.table.summary <- function(baseplot,
@@ -452,181 +416,6 @@ crosstabsum <- function(x, grp, weight.by) {
 }
 
 
-# checks at which position in fitted models factors with
-# more than two levels are located.
-#' @importFrom stats model.frame
-retrieveModelGroupIndices <- function(models, rem_rows = NULL) {
-  # init group-row-indices
-  group.pred.rows <- c()
-  group.pred.labs <- c()
-  group.pred.span <- c()
-  found.factors <- c()
-  add.index <- 0
-  # ------------------------
-  # retrieve fitted models
-  # ------------------------
-  # go through fitted models
-  for (k in seq_len(length(models))) {
-    # get model
-    fit <- models[[k]]
-    # copy model frame
-    if (is_merMod(fit))
-      fmodel <- stats::model.frame(fit, fixed.only = T)
-    else
-      fmodel <- stats::model.frame(fit)
-    # retrieve all factors from model
-    for (grp.cnt in seq_len(ncol(fmodel))) {
-      # get variable
-      fit.var <- fmodel[, grp.cnt]
-      # is factor? and has more than two levels?
-      # (otherwise, only one category would appear in
-      # coefficients, so no grouping needed anyway)
-      if (is.factor(fit.var) && nlevels(fit.var) > 2) {
-        # get factor name
-        fac.name <- colnames(fmodel)[grp.cnt]
-        # check whether we already have this factor
-        if (!any(found.factors == fac.name)) {
-          # if not, save found factor variable name
-          found.factors <- c(found.factors, fac.name)
-          # save factor name
-          lab <- unname(sjlabelled::get_label(fit.var, def.value = fac.name))
-          # determins startindex
-          index <- grp.cnt + add.index - 1
-          index.add <- nlevels(fit.var) - 2
-          # save row index, so we know where to start group
-          group.pred.rows <- c(group.pred.rows, index)
-          group.pred.span <- c(group.pred.span, index:(index + index.add))
-          group.pred.labs <- c(group.pred.labs, lab)
-          # increase add.index by amount of factor levels (minus reference cat.)
-          add.index <- add.index + index.add
-        } else {
-          add.index <- add.index + nlevels(fit.var) - 2
-        }
-      }
-    }
-  }
-  # have any groups? if not, reset row-index-counter
-  if (length(group.pred.rows) < 1) {
-    group.pred.rows <- NULL
-    group.pred.labs <- NULL
-    group.pred.span <- NULL
-  }
-  # do we have any rows removed?
-  else if (!is.null(rem_rows)) {
-    # any non-computed row-indices left?
-    while (length(rem_rows) > 0) {
-      # take care, while loop!
-      any.found <- FALSE
-      # if yes, go through all grouping row indices
-      for (i in seq_len(length(group.pred.rows))) {
-        # if yes, check if removed row was before
-        # grouped row indes
-        if (length(rem_rows) > 0 && rem_rows[1] <= group.pred.rows[i]) {
-          # if yes, iterate all remaining group indices
-          for (j in i:length(group.pred.rows)) {
-            # and reduce index number (because of removed rows)
-            group.pred.rows[j] <- group.pred.rows[j] - 1
-          }
-          # where does span for grouping start?
-          start <- min(which(group.pred.span >= rem_rows[1]))
-          for (j in start:length(group.pred.span)) {
-            # and reduce index number (because of removed rows)
-            group.pred.span[j] <- group.pred.span[j] - 1
-          }
-          # reduce indices
-          rem_rows <- rem_rows - 1
-          # remove computed row-index
-          rem_rows <- rem_rows[-1]
-          # found something!
-          any.found <- TRUE
-        }
-      }
-      # removed any index? if not, break loop
-      if (!any.found) break
-    }
-  }
-  return(list(group.pred.rows,
-              group.pred.span,
-              group.pred.labs))
-}
-
-
-# automatically retrieve predictor labels
-# of fitted (g)lm
-#' @importFrom stats formula terms
-retrieveModelLabels <- function(models, group.pred) {
-  fit.labels <- c()
-  for (k in seq_len(length(models))) {
-    # get model
-    fit <- models[[k]]
-    # any valid model?
-    if (inherits(fit, c("plm", "ppgls"))) return(NULL)
-    # get model coefficients' names
-    if (is_merMod(fit)) {
-      coef_names <- names(lme4::fixef(fit))
-      # get model frame
-      m_f <- stats::model.frame(fit, fixed.only = TRUE)
-    } else {
-      coef_names <- names(stats::coef(fit))
-      # get model frame
-      m_f <- stats::model.frame(fit)
-    }
-    # for NULL-models, we just have one column in model frame
-    if (ncol(m_f) > 1) {
-      # iterate coefficients (1 is intercept or response)
-      for (i in 2:ncol(m_f)) {
-        # check bounds
-        if (i <= length(coef_names)) {
-          # get predictor
-          pvar <- m_f[, i]
-          # check if we have a variable label
-          lab <- sjlabelled::get_label(pvar, def.value = colnames(m_f)[i])
-          # get model coefficients' names
-          coef_name <- coef_names[i]
-          # is predictor a factor?
-          # if yes, we have this variable multiple
-          # times, so manually set value labels
-          if (is.factor(pvar)) {
-            # get amount of levels
-            pvar.len <- nlevels(pvar)
-            # get value labels, if any
-            pvar.lab <- sjlabelled::get_labels(pvar)
-            # have any labels, and have we same amount of labels
-            # as factor levels?
-            if (!is.null(pvar.lab) && length(pvar.lab) == pvar.len) {
-              # create labels
-              if (group.pred && pvar.len > 2) {
-                # if predictor grouping is enabled, don't use variable labels again
-                labels.to.add <- pvar.lab[2:pvar.len]
-              } else {
-                # else, if we have not grouped predictors, we have no headin
-                # with variable label, hence, factor levels may not be intuitiv.
-                # thus, add variable label so values have a meaning
-                labels.to.add <- sprintf("%s (%s)", lab, pvar.lab[2:pvar.len])
-              }
-              fit.labels <- c(fit.labels, labels.to.add)
-            } else {
-              fit.labels <- c(fit.labels, coef_name)
-            }
-          } else {
-            if (!any(fit.labels == lab)) fit.labels <- c(fit.labels, lab)
-          }
-        }
-      }
-    }
-  }
-  unique(fit.labels)
-}
-
-
-# compute chi-square for glm
-Chisquare.glm <- function(rr, digits = 3) {
-  return(with(rr, pchisq(null.deviance - deviance,
-                         df.null - df.residual,
-                         lower.tail = FALSE), digits = digits))
-}
-
-
 # Erzeugt eine rotierte Faktorladungen einer Hauptkomponentenanalyse
 # (Paramter "data") mit einer bestimmten Anzahl an Faktoren (Parameter "factors")
 # auf Grundlage der Varimax-Rotation
