@@ -34,20 +34,12 @@
 #'             If \code{data} has more than one variable, a plot for each
 #'             variable in \code{data} is plotted.
 #'             }
-#'             \item{\code{"gpt"}}{calls \code{\link{sjp.gpt}}. The first
-#'             three variables in \code{data} are used (and required) to create the plot.
-#'             }
 #'             \item{\code{"grpfrq"}}{calls \code{\link{sjp.grpfrq}}. The first
 #'             two variables in \code{data} are used (and required) to create the plot.
 #'             }
-#'             \item{\code{"likert"}}{calls \code{\link{sjp.likert}}. \code{data}
+#'             \item{\code{"likert"}}{calls \code{\link{plot_likert}}. \code{data}
 #'             must be a data frame with items to plot.
 #'             }
-#'             \item{\code{"scatter"}}{calls \code{\link{sjp.scatter}}. The first
-#'             two variables in \code{data} are used (and required) to create the plot;
-#'             if \code{data} also has a third variable, this is used as grouping-
-#'             variable in \code{sjp.scatter}.
-#'             }
 #'             \item{\code{"stackfrq"}}{calls \code{\link{sjp.stackfrq}} or \code{\link{sjt.stackfrq}}.
 #'             \code{data} must be a data frame with items to create the plot or table.
 #'             }
@@ -71,11 +63,6 @@
 #' efc %>% sjplot(e17age, c172code, fun = "grpfrq",
 #'                type = "box", geom.colors = "Set1")
 #'
-#' # scatter plot, grouped
-#' efc %>%
-#'   select(e42dep, c172code, c161sex) %>%
-#'   sjplot(fun = "scatter")
-#'
 #' # frequencies, as plot grid
 #' efc %>%
 #'   select(e42dep, c172code, e16sex, c161sex) %>%
@@ -97,12 +84,11 @@
 #'
 #' @importFrom sjmisc is_empty
 #' @importFrom sjlabelled copy_labels get_label get_labels
-#' @importFrom dplyr select_ filter
+#' @importFrom dplyr filter
 #' @importFrom tidyr nest
 #' @importFrom stats complete.cases
 #' @export
-sjplot <- function(data, ..., fun = c("frq", "grpfrq", "xtab", "gpt", "scatter",
-                                      "aov1", "likert", "stackfrq")) {
+sjplot <- function(data, ..., fun = c("frq", "grpfrq", "xtab", "aov1", "likert", "stackfrq")) {
   # check if x is a data frame
   if (!is.data.frame(data)) stop("`data` must be a data frame.", call. = F)
 
@@ -223,7 +209,6 @@ sjtab <- function(data, ..., fun = c("xtab", "stackfrq")) {
         page.complete = final.table,
         knitr = final.knitr,
         file = eval(args[["file"]]),
-        show = if (is.null(args[["no.output"]])) TRUE else !eval(args[["no.output"]]),
         viewer = if (is.null(args[["use.viewer"]])) TRUE else eval(args[["use.viewer"]])
       )
     ))
@@ -234,6 +219,22 @@ sjtab <- function(data, ..., fun = c("xtab", "stackfrq")) {
 }
 
 
+get_grouped_plottitle <- function(x, grps, i, sep = "\n") {
+  # prepare title for group
+  tp <- get_title_part(x, grps, 1, i)
+  title <- sprintf("%s: %s", tp[1], tp[2])
+
+  # do we have another groupng variable?
+  if (length(attr(x, "vars", exact = T)) > 1) {
+    # prepare title for group
+    tp <- get_title_part(x, grps, 2, i)
+    title <- sprintf("%s%s%s: %s", title, sep, tp[1], tp[2])
+  }
+
+  title
+}
+
+
 get_grouped_title <- function(x, grps, args, i, sep = "\n") {
   # prepare title for group
   tp <- get_title_part(x, grps, 1, i)
@@ -251,6 +252,7 @@ get_grouped_title <- function(x, grps, args, i, sep = "\n") {
 }
 
 
+#' @importFrom sjlabelled get_values get_label get_labels
 get_title_part <- function(x, grps, level, i) {
   # prepare title for group
   var.name <- colnames(grps)[level]
@@ -274,16 +276,20 @@ get_title_part <- function(x, grps, level, i) {
 }
 
 
+#' @importFrom rlang .data
+#' @importFrom dplyr select filter
+#' @importFrom stats complete.cases
+#'
 get_grouped_data <- function(x) {
   # nest data frame
   grps <- tidyr::nest(x)
 
   # remove NA category
   cc <- grps %>%
-    dplyr::select_("-data") %>%
+    dplyr::select(-.data$data) %>%
     stats::complete.cases()
   # select only complete cases
-  grps <- grps %>% dplyr::filter(cc)
+  grps <- grps %>% dplyr::filter(!! cc)
 
   # arrange data
   if (length(attr(x, "vars", exact = T)) == 1)
@@ -305,49 +311,35 @@ plot_sj <- function(x, fun, args) {
     if (fun == "frq") {
       pl <- list()
       for (i in seq_len(ncol(x))) {
-        pl[[length(pl) + 1]] <- sjp.frq(x[[i]], prnt.plot = F)$plot
+        pl[[length(pl) + 1]] <- sjp.frq(x[[i]])
       }
     } else if (fun  == "grpfrq") {
-      p <- sjp.grpfrq(x[[1]], x[[2]], prnt.plot = F)$plot
+      p <- sjp.grpfrq(x[[1]], x[[2]])
     } else if (fun  == "likert") {
-      p <- sjp.likert(x, prnt.plot = F)$plot
+      p <- plot_likert(x)
     } else if (fun  == "stackfrq") {
-      p <- sjp.stackfrq(x, prnt.plot = F)$plot
+      p <- sjp.stackfrq(x)
     } else if (fun  == "xtab") {
-      p <- sjp.xtab(x[[1]], x[[2]], prnt.plot = F)$plot
-    } else if (fun  == "gpt") {
-      p <- sjp.gpt(x[[1]], x[[2]], x[[3]], prnt.plot = F)$plot
-    } else if (fun  == "scatter") {
-      if (ncol(x) >= 3)
-        p <- sjp.scatter(x[[1]], x[[2]], x[[3]], prnt.plot = F)$plot
-      else
-        p <- sjp.scatter(x[[1]], x[[2]], prnt.plot = F)$plot
+      p <- sjp.xtab(x[[1]], x[[2]])
     } else if (fun  == "aov1") {
-      p <- sjp.aov1(x[[1]], x[[2]], prnt.plot = F)$plot
+      p <- sjp.aov1(x[[1]], x[[2]])
     }
   } else {
     if (fun == "frq") {
       pl <- list()
       for (i in seq_len(ncol(x))) {
-        pl[[length(pl) + 1]] <- do.call(sjp.frq, args = c(list(var.cnt = x[[i]], prnt.plot = F), args))$plot
+        pl[[length(pl) + 1]] <- do.call(sjp.frq, args = c(list(var.cnt = x[[i]]), args))
       }
     } else if (fun  == "grpfrq") {
-      p <- do.call(sjp.grpfrq, args = c(list(var.cnt = x[[1]], var.grp = x[[2]], prnt.plot = F), args))$plot
+      p <- do.call(sjp.grpfrq, args = c(list(var.cnt = x[[1]], var.grp = x[[2]]), args))
     } else if (fun  == "likert") {
-      p <- do.call(sjp.likert, args = c(list(items = x, prnt.plot = F), args))$plot
+      p <- do.call(plot_likert, args = c(list(items = x), args))
     } else if (fun  == "stackfrq") {
-      p <- do.call(sjp.stackfrq, args = c(list(items = x, prnt.plot = F), args))$plot
+      p <- do.call(sjp.stackfrq, args = c(list(items = x), args))
     } else if (fun  == "xtab") {
-      p <- do.call(sjp.xtab, args = c(list(x = x[[1]], grp = x[[2]], prnt.plot = F), args))$plot
-    } else if (fun  == "gpt") {
-      p <- do.call(sjp.gpt, args = c(list(x = x[[1]], y = x[[2]], groups = x[[3]], prnt.plot = F), args))$plot
-    } else if (fun  == "scatter") {
-      if (ncol(x) >= 3)
-        p <- do.call(sjp.scatter, args = c(list(x = x[[1]], y = x[[2]], grp = x[[3]], prnt.plot = F), args))$plot
-      else
-        p <- do.call(sjp.scatter, args = c(list(x = x[[1]], y = x[[2]], prnt.plot = F), args))$plot
+      p <- do.call(sjp.xtab, args = c(list(x = x[[1]], grp = x[[2]]), args))
     } else if (fun  == "aov1") {
-      p <- do.call(sjp.aov1, args = c(list(var.dep = x[[1]], var.grp = x[[2]], prnt.plot = F), args))$plot
+      p <- do.call(sjp.aov1, args = c(list(var.dep = x[[1]], var.grp = x[[2]]), args))
     }
   }
 
